@@ -9,23 +9,23 @@ from sqlalchemy.orm.collections import InstrumentedList
 class HasActivitiesMixin(object):
     __versioned__ = {}
 
-    activityUuid = Column(UUID(as_uuid=True),
-                          default=uuid4)
+    activityIdentifier = Column(UUID(as_uuid=True),
+                                     default=uuid4)
 
     @property
-    def activities(self):
+    def __activities__(self):
         Activity = Activator.get_activity()
         query_filter = (Activity.table_name == self.__tablename__) & \
-                       (Activity.uuid == self.activityUuid) & \
+                       (Activity.entityIdentifier == self.activityIdentifier) & \
                        (Activity.verb != None)
         return InstrumentedList(Activity.query.filter(query_filter) \
                                               .order_by(desc(Activity.id)) \
                                               .all())
 
     @property
-    def insertActivity(self):
+    def __insertActivity__(self):
         Activity = Activator.get_activity()
         query_filter = (Activity.table_name == self.__tablename__) & \
-                       (Activity.uuid == self.activityUuid) & \
+                       (Activity.entityIdentifier == self.activityIdentifier) & \
                        (Activity.verb == 'insert')
         return Activity.query.filter(query_filter).one()
